@@ -10,10 +10,18 @@
 static int create_node(const sqfs_tree_node_t *n, const char *name, int flags)
 {
 	WCHAR *wpath;
+	char *fixed;
 	HANDLE fh;
 	(void)flags;
 
-	wpath = path_to_windows(name);
+	fixed = fix_win32_filename(name);
+	if (fixed == NULL) {
+		fputs("create_node: out of memory!\n", stderr);
+		return -1;
+	}
+
+	wpath = path_to_windows(fixed);
+	free(fixed);
 	if (wpath == NULL)
 		return -1;
 
@@ -40,11 +48,19 @@ static int create_node(const sqfs_tree_node_t *n, const char *name, int flags)
 
 	free(wpath);
 	return 0;
-fail:
-	fprintf(stderr, "Creating %s: %ld\n", name, GetLastError());
+fail: {
+	DWORD err = GetLastError();
 	free(wpath);
+	SetLastError(err);
+	w32_perror(name);
+
+	if (err == ERROR_FILE_EXISTS) {
+		fputs("\nHINT: this could be caused by case "
+		      "sensitivity on Windows.\n", stderr);
+	}
 	return -1;
 }
+}
 #else
 static int create_node(const sqfs_tree_node_t *n, const char *name, int flags)
 {
@@ -121,7 +137,7 @@ static int create_node_dfs(const sqfs_tree_node_t *n, int flags)
 	char *name;
 	int ret;
 
-	if (!is_filename_sane((const char *)n->name, true)) {
+	if (!is_filename_sane((const char *)n->name)) {
 		fprintf(stderr, "Found an entry named '%s', skipping.\n",
 			n->name);
 		return 0;
@@ -216,7 +232,7 @@ static int set_attribs(sqfs_xattr_reader_t *xattr,
 	char *path;
 	int ret;
 
-	if (!is_filename_sane((const char *)n->name, true))
+	if (!is_filename_sane((const char *)n->name))
 		return 0;
 
 	if (S_ISDIR(n->inode->base.mode)) {
@@ -235,6 +251,19 @@ static int set_attribs(sqfs_xattr_reader_t *xattr,
 	ret = canonicalize_name(path);
 	assert(ret == 0);
 
+#if defined(_WIN32) || defined(__WINDOWS__)
+	{
+		char *fixed = fix_win32_filename(path);
+		if (fixed == NULL) {
+			sqfs_perror(path, "fixing Windows path",
+				    SQFS_ERROR_ALLOC);
+			sqfs_free(path);
+			return -1;
+		}
+		path = fixed;
+	}
+#endif
+
 #ifdef HAVE_SYS_XATTR_H
 	if ((flags & UNPACK_SET_XATTR) && xattr != NULL) {
 		if (set_xattr(path, xattr, n))
