@@ -9,7 +9,10 @@
 
 #include "config.h"
 #include "common.h"
-#include "tar.h"
+
+#include "util/util.h"
+#include "tar/tar.h"
+#include "io/xfrm.h"
 
 #include <getopt.h>
 #include <string.h>
