@@ -20,10 +20,11 @@
 
 #include "simple_writer.h"
 #include "compress_cli.h"
-#include "fstream.h"
+#include "io/ostream.h"
+#include "io/file.h"
+#include "io/std.h"
 #include "compat.h"
 #include "fstree.h"
-#include "tar.h"
 
 #include <stddef.h>
 
@@ -33,13 +34,6 @@ typedef struct sqfs_hard_link_t {
 	char *target;
 } sqfs_hard_link_t;
 
-#define container_of(ptr, type, member) \
-	((type *)((char *)ptr - offsetof(type, member)))
-
-int inode_stat(const sqfs_tree_node_t *node, struct stat *sb);
-
-char *sqfs_tree_node_get_path(const sqfs_tree_node_t *node);
-
 int sqfs_data_reader_dump(const char *name, sqfs_data_reader_t *data,
 			  const sqfs_inode_generic_t *inode,
 			  ostream_t *fp, size_t block_size);
@@ -53,14 +47,6 @@ void sqfs_perror(const char *file, const char *action, int error_code);
 int sqfs_tree_find_hard_links(const sqfs_tree_node_t *root,
 			      sqfs_hard_link_t **out);
 
-/*
-  A wrapper around mkdir() that behaves like 'mkdir -p'. It tries to create
-  every component of the given path and skips already existing entries.
-
-  Returns 0 on success.
-*/
-int mkdir_p(const char *path);
-
 /* A common implementation of the '--version' command line flag. */
 void print_version(const char *progname);
 
