@@ -33,7 +33,10 @@
 #define SQFS_VERSION_MAJOR 4
 #define SQFS_VERSION_MINOR 0
 #define SQFS_DEVBLK_SIZE 4096
-#define SQFS_DEFAULT_BLOCK_SIZE 131072
+
+#define SQFS_MIN_BLOCK_SIZE (4 * 1024)
+#define SQFS_MAX_BLOCK_SIZE (1024 * 1024)
+#define SQFS_DEFAULT_BLOCK_SIZE (128 * 1024)
 
 /**
  * @struct sqfs_super_t
@@ -237,7 +240,7 @@ typedef enum {
 	/**
 	 * @brief Set to indicate that data blocks have not been deduplicated.
 	 */
-	SQFS_FLAG_DUPLICATES = 0x0040,
+	SQFS_FLAG_NO_DUPLICATES = 0x0040,
 
 	/**
 	 * @brief Set to indicate that an NFS export table is present.
