@@ -61,10 +61,19 @@ void sqfs_perror(const char *file, const char *action, int error_code)
 	case SQFS_ERROR_ARG_INVALID:
 		errstr = "invalid argument";
 		break;
+	case SQFS_ERROR_SEQUENCE:
+		errstr = "illegal oder of operations";
+		break;
 	default:
 		errstr = "libsquashfs returned an unknown error code";
 		break;
 	}
 
-	fprintf(stderr, "%s: %s: %s.\n", file, action, errstr);
+	if (file != NULL)
+		fprintf(stderr, "%s: ", file);
+
+	if (action != NULL)
+		fprintf(stderr, "%s: ", action);
+
+	fprintf(stderr, "%s.\n", errstr);
 }
