@@ -12,7 +12,7 @@
 #include "sqfs/error.h"
 #include "sqfs/block.h"
 #include "sqfs/io.h"
-#include "util.h"
+#include "util/util.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -147,8 +147,13 @@ int sqfs_meta_reader_seek(sqfs_meta_reader_t *m, sqfs_u64 block_start,
 void sqfs_meta_reader_get_position(const sqfs_meta_reader_t *m,
 				   sqfs_u64 *block_start, size_t *offset)
 {
-	*block_start = m->block_offset;
-	*offset = m->offset;
+	if (m->offset == m->data_used) {
+		*block_start = m->next_block;
+		*offset = 0;
+	} else {
+		*block_start = m->block_offset;
+		*offset = m->offset;
+	}
 }
 
 int sqfs_meta_reader_read(sqfs_meta_reader_t *m, void *data, size_t size)
