@@ -20,7 +20,10 @@ int sqfs_super_init(sqfs_super_t *super, size_t block_size, sqfs_u32 mtime,
 	if (block_size & (block_size - 1))
 		return SQFS_ERROR_SUPER_BLOCK_SIZE;
 
-	if (block_size < 4096 || block_size > (1 << 20))
+	if (block_size < SQFS_MIN_BLOCK_SIZE)
+		return SQFS_ERROR_SUPER_BLOCK_SIZE;
+
+	if (block_size > SQFS_MAX_BLOCK_SIZE)
 		return SQFS_ERROR_SUPER_BLOCK_SIZE;
 
 	memset(super, 0, sizeof(*super));
@@ -29,6 +32,7 @@ int sqfs_super_init(sqfs_super_t *super, size_t block_size, sqfs_u32 mtime,
 	super->block_size = block_size;
 	super->compression_id = compressor;
 	super->flags = SQFS_FLAG_NO_FRAGMENTS | SQFS_FLAG_NO_XATTRS;
+	super->flags |= SQFS_FLAG_NO_DUPLICATES;
 	super->version_major = SQFS_VERSION_MAJOR;
 	super->version_minor = SQFS_VERSION_MINOR;
 	super->bytes_used = sizeof(*super);
