@@ -7,8 +7,8 @@
 #include "config.h"
 
 #include "fstree.h"
-#include "internal.h"
-#include "../test.h"
+#include "util/test.h"
+#include "util/util.h"
 
 int main(int argc, char **argv)
 {
