@@ -6,7 +6,8 @@
  */
 #include "config.h"
 
-#include "tar.h"
+#include "io/file.h"
+#include "tar/tar.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -33,7 +34,7 @@ int main(int argc, char **argv)
 		if (ret < 0)
 			goto fail;
 
-		ret = istream_skip(fp, hdr.sb.st_size);
+		ret = istream_skip(fp, hdr.record_size);
 
 		clear_header(&hdr);
 		if (ret < 0)
