@@ -5,8 +5,9 @@
  * Copyright (C) 2019 David Oberhollenzer <goliath@infraroot.at>
  */
 #include "config.h"
-#include "tar.h"
-#include "../test.h"
+#include "io/file.h"
+#include "tar/tar.h"
+#include "util/test.h"
 
 static const uint8_t value[] = {
 	0x00, 0x00, 0x00, 0x02,
@@ -26,11 +27,10 @@ int main(int argc, char **argv)
 	fp = istream_open_file(STRVALUE(TESTPATH) "/" STRVALUE(TESTFILE));
 	TEST_NOT_NULL(fp);
 	TEST_ASSERT(read_header(fp, &hdr) == 0);
-	TEST_EQUAL_UI(hdr.sb.st_mode, S_IFREG | 0644);
-	TEST_EQUAL_UI(hdr.sb.st_uid, 01750);
-	TEST_EQUAL_UI(hdr.sb.st_gid, 01750);
-	TEST_EQUAL_UI(hdr.sb.st_size, 5);
-	TEST_EQUAL_UI(hdr.sb.st_mtime, 1543094477);
+	TEST_EQUAL_UI(hdr.mode, S_IFREG | 0644);
+	TEST_EQUAL_UI(hdr.uid, 01750);
+	TEST_EQUAL_UI(hdr.gid, 01750);
+	TEST_EQUAL_UI(hdr.actual_size, 5);
 	TEST_EQUAL_UI(hdr.mtime, 1543094477);
 	TEST_STR_EQUAL(hdr.name, "input.txt");
 	TEST_ASSERT(!hdr.unknown_record);
