@@ -6,8 +6,8 @@
  */
 #include "config.h"
 
-#include "../test.h"
-#include "util.h"
+#include "util/test.h"
+#include "util/util.h"
 
 int main(int argc, char **argv)
 {
