@@ -6,8 +6,8 @@
  */
 #include "config.h"
 
-#include "rbtree.h"
-#include "../test.h"
+#include "util/rbtree.h"
+#include "util/test.h"
 
 static int key_compare(const void *ctx, const void *a, const void *b)
 {
