@@ -6,10 +6,10 @@
  */
 #include "config.h"
 
-#include "str_table.h"
-#include "fstream.h"
+#include "util/str_table.h"
+#include "io/file.h"
 #include "compat.h"
-#include "../test.h"
+#include "util/test.h"
 
 static char *strings[1000];
 
